Documentation
¶
Overview ¶
Copyright 2018 StreamSets Inc. Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
Copyright 2018 StreamSets Inc. Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
Index ¶
Constants ¶
const ( DefaultLogFilePath = "/log/edge.log" DefaultConfigFilePath = "/etc/edge.conf" LogFileName = "edge.log" DEBUG = "DEBUG" WARN = "WARN" ERROR = "ERROR" INFO = "INFO" )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Config ¶
type Config struct {
LogDir string `toml:"log-dir"`
Execution execution.Config
Http http.Config
SCH controlhub.Config
Process process.Config
}
Config represents the configuration format for the Data Collector Edge binary.
func (*Config) FromTomlFile ¶
FromTomlFile loads the config from a TOML file.
func (*Config) ToTomlFile ¶
type ContextHook ¶
type ContextHook struct{}
func (ContextHook) Fire ¶
func (hook ContextHook) Fire(entry *log.Entry) error
Adds file/line info to logrus fields
func (ContextHook) Levels ¶
func (hook ContextHook) Levels() []log.Level
type DataCollectorEdgeMain ¶
type DataCollectorEdgeMain struct {
Config *Config
BuildInfo *common.BuildInfo
RuntimeInfo *common.RuntimeInfo
WebServerTask *http.WebServerTask
PipelineStoreTask store.PipelineStoreTask
Manager manager.Manager
DPMMessageEventHandler *controlhub.MessageEventHandler
// contains filtered or unexported fields
}