Documentation
¶
Overview ¶
Copyright 2018 StreamSets Inc. Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
Copyright 2018 StreamSets Inc. Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
Index ¶
Constants ¶
const ( List = "LIST" ListMap = "LIST_MAP" WithHeader = "WITH_HEADER" IgnoreHeader = "IGNORE_HEADER" NoHeader = "NO_HEADER" Custom = "CUSTOM" )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type DelimitedReaderFactoryImpl ¶
type DelimitedReaderFactoryImpl struct {
recordio.AbstractRecordReaderFactory
CsvFileFormat string
CsvHeader string
CsvAllowExtraColumns bool
CsvExtraColumnPrefix string
CsvMaxObjectLen float64
CsvCustomDelimiter string
CsvCustomEscape string
CsvEnableComments bool
CsvCommentMarker string
CsvIgnoreEmptyLines bool
CsvRecordType string
CsvSkipStartLines float64
ParseNull bool
NullConstant string
}
func (*DelimitedReaderFactoryImpl) CreateReader ¶
func (j *DelimitedReaderFactoryImpl) CreateReader( context api.StageContext, reader io.Reader, messageId string, ) (dataformats.RecordReader, error)
type DelimitedReaderImpl ¶
type DelimitedReaderImpl struct {
// contains filtered or unexported fields
}
func (*DelimitedReaderImpl) Close ¶
func (delimitedReader *DelimitedReaderImpl) Close() error
func (*DelimitedReaderImpl) CreateRecord ¶
func (delimitedReader *DelimitedReaderImpl) CreateRecord(columns []string) (api.Record, error)
func (*DelimitedReaderImpl) ReadRecord ¶
func (delimitedReader *DelimitedReaderImpl) ReadRecord() (api.Record, error)
type RecordCreator ¶
func (*RecordCreator) CreateRecord ¶
func (r *RecordCreator) CreateRecord( context api.StageContext, lineText string, messageId string, headers []*api.Field, ) (api.Record, error)